@@ -1,7 +1,7 @@
 package Media::Info::Mplayer;
 
-our $DATE = '2016-04-05'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-04-06'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -30,6 +30,10 @@ $SPEC{get_media_info} = {
             pos     => 0,
             req     => 1,
         },
+        audio_info => {
+            schema => 'bool',
+            default => 1,
+        },
     },
     deps => {
         prog => 'mplayer',
@@ -39,6 +43,7 @@ sub get_media_info {
     require File::Which;
 
     my %args = @_;
+    my $audio_info = $args{audio_info} // 1;
 
     File::Which::which("mplayer")
           or return err(412, "Can't find mplayer in PATH");
@@ -50,7 +55,9 @@ sub get_media_info {
     my ($stdout, $stderr, $exit) = capture {
         local $ENV{LANG} = "C";
         system("mplayer", "-identify", $media,
-               "-quiet", "-nosound", "-msglevel", "all=0", "-frames", "0");
+               "-quiet",
+               ("-nosound") x ($audio_info ? 0:1),
+               "-msglevel", "all=0", "-frames", "0");
     };
 
     return err(500, "Can't execute mplayer ($exit)") if $exit;
@@ -95,7 +102,7 @@ Media::Info::Mplayer - Return information on media file/URL, using mplayer
 
 =head1 VERSION
 
-This document describes version 0.06 of Media::Info::Mplayer (from Perl distribution Media-Info-Mplayer), released on 2016-04-05.
+This document describes version 0.07 of Media::Info::Mplayer (from Perl distribution Media-Info-Mplayer), released on 2016-04-06.
 
 =head1 SYNOPSIS
 
@@ -137,6 +144,8 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<audio_info> => I<bool> (default: 1)
+
 =item * B<media>* => I<str>
 
 Media file/URL.
